@@ -68,9 +68,7 @@ class RecorderReader:
 
     def __init__(self, logs_dir):
         current_dir = os.path.abspath(os.path.dirname(__file__))
-        parent_dir = os.path.abspath(os.path.join(current_dir, os.pardir))
-        lib_dir = os.path.abspath(os.path.join(parent_dir, 'lib'))
-        search_path = os.path.abspath(os.path.join(lib_dir, 'librreader*.so'))
+        search_path = os.path.abspath(os.path.join(current_dir, 'librreader*.so'))
 
         libreader_path = ''
         found = glob.glob(search_path)
